#
# Cookbook:: gemstash
# Recipe:: prerequesites
#
# Copyright:: 2020, tecRacer Opensource, Apache-2.0.

# apt_update 'update'

case node['platform']
when 'ubuntu', 'debian'
  node.default['gemstash']['sqlite']['dev_package'] = 'libsqlite3-dev'

when 'redhat', 'centos', 'amazon'
  node.default['gemstash']['sqlite']['dev_package'] = 'sqlite-devel'

  if platform?('centos') && node['platform_version'].to_i >= 8
    execute 'yum --enablerepo=PowerTools install libyaml-devel -y'
  end

when 'opensuseleap'
  node.default['gemstash']['sqlite']['dev_package'] = 'sqlite3-devel'

end

package node['gemstash']['sqlite']['dev_package']

# user and group creation
group node['gemstash']['user']['group'] do
  system true
end

user node['gemstash']['user']['name'] do
  comment 'User for Gemstash server'
  group node['gemstash']['user']['group']
  home '/var/lib/gemstash'
  shell '/usr/sbin/nologin'
  system true
end

directory '/var/lib/gemstash' do
  user node['gemstash']['user']['name']
  group node['gemstash']['user']['group']
end

# Keeps the rbenv install upto date
rbenv_user_install node['gemstash']['user']['name']

rbenv_plugin 'ruby-build' do
  git_url 'https://github.com/rbenv/ruby-build.git'
  user node['gemstash']['user']['name']
end

rbenv_ruby node['gemstash']['ruby']['version'] do
  user node['gemstash']['user']['name']
end

rbenv_global node['gemstash']['ruby']['version'] do
  user node['gemstash']['user']['name']
end
